.. image:: logo/BBP-Morphology-Workflows.jpg

.. mdinclude:: ../../README.md
    :start-line: 2

.. toctree::
   :hidden:
   :maxdepth: 2

   Home <self>
   cli
   luigi_cfg
   api_ref
   changelog
   contributing
